@@ -39,6 +39,9 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
               start= None,end= None,step = None,  \
               outstart = None, outend = None, outstep = None, \
               crop = False):
+    ''' indata: input data
+    '''
+        
     if (cocosel == None):
         # if coordinates not given, make it from the start, end, step arguments
         if (coords == None):
